@@ -30,16 +30,16 @@
 
 #include "panel-applets-manager-dbus.h"
 
-G_DEFINE_TYPE (PanelAppletsManagerDBus,
-               panel_applets_manager_dbus,
-               PANEL_TYPE_APPLETS_MANAGER)
-
 struct _PanelAppletsManagerDBusPrivate
 {
 	GHashTable *applet_factories;
 	GList      *monitors;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (PanelAppletsManagerDBus,
+                            panel_applets_manager_dbus,
+                            PANEL_TYPE_APPLETS_MANAGER)
+
 typedef gint (* ActivateAppletFunc) (void);
 typedef GtkWidget * (* GetAppletWidgetFunc) (const gchar *factory_id,
                                              guint        uid);
@@ -69,10 +69,7 @@ panel_applet_factory_info_free (PanelAppletFactoryInfo *info)
 
 	g_free (info->id);
 	g_free (info->location);
-	g_list_foreach (info->applet_list,
-			(GFunc) panel_applet_info_free,
-			NULL);
-	g_list_free (info->applet_list);
+	g_list_free_full (info->applet_list, (GDestroyNotify) panel_applet_info_free);
 	info->applet_list = NULL;
 	g_free (info->srcdir);
 
@@ -285,8 +282,7 @@ applets_directory_changed (GFileMonitor     *monitor,
         }
     }
 
-  g_slist_foreach (dirs, (GFunc) g_free, NULL);
-  g_slist_free (dirs);
+  g_slist_free_full (dirs, g_free);
 }
 
 static void
@@ -547,14 +543,30 @@ panel_applets_manager_dbus_get_new_iid (PanelAppletsManager *manager,
 	return NULL;
 }
 
+static gboolean
+panel_applets_manager_dbus_open_initial_setup_dialog (PanelAppletsManager    *manager,
+                                                      const gchar            *iid,
+                                                      GtkWindow              *parent,
+                                                      GpInitialSetupCallback  callback,
+                                                      gpointer                user_data,
+                                                      GDestroyNotify          free_func)
+{
+  return FALSE;
+}
+
+static GtkWidget *
+panel_applets_manager_dbus_get_standalone_menu (PanelAppletsManager *manager)
+{
+  return NULL;
+}
+
 static void
 panel_applets_manager_dbus_finalize (GObject *object)
 {
 	PanelAppletsManagerDBus *manager = PANEL_APPLETS_MANAGER_DBUS (object);
 
 	if (manager->priv->monitors) {
-		g_list_foreach (manager->priv->monitors, (GFunc) g_object_unref, NULL);
-		g_list_free (manager->priv->monitors);
+		g_list_free_full (manager->priv->monitors, g_object_unref);
 		manager->priv->monitors = NULL;
 	}
 
@@ -569,9 +581,7 @@ panel_applets_manager_dbus_finalize (GObject *object)
 static void
 panel_applets_manager_dbus_init (PanelAppletsManagerDBus *manager)
 {
-	manager->priv = G_TYPE_INSTANCE_GET_PRIVATE (manager,
-						     PANEL_TYPE_APPLETS_MANAGER_DBUS,
-						     PanelAppletsManagerDBusPrivate);
+	manager->priv = panel_applets_manager_dbus_get_instance_private (manager);
 
 	manager->priv->applet_factories = g_hash_table_new_full (g_str_hash,
 								 g_str_equal,
@@ -596,6 +606,6 @@ panel_applets_manager_dbus_class_init (PanelAppletsManagerDBusClass *class)
 	manager_class->load_applet = panel_applets_manager_dbus_load_applet;
 	manager_class->get_applet_widget = panel_applets_manager_dbus_get_applet_widget;
 	manager_class->get_new_iid = panel_applets_manager_dbus_get_new_iid;
-
-	g_type_class_add_private (class, sizeof (PanelAppletsManagerDBusPrivate));
+	manager_class->open_initial_setup_dialog = panel_applets_manager_dbus_open_initial_setup_dialog;
+	manager_class->get_standalone_menu = panel_applets_manager_dbus_get_standalone_menu;
 }
