@@ -203,30 +203,6 @@ panel_key_file_load_from_uri (GKeyFile       *keyfile,
 	return result;
 }
 
-gboolean
-panel_key_file_copy_and_mark_trusted (const char  *source_path,
-				      const char  *target_path,
-				      GError     **error)
-{
-	GKeyFile *key_file;
-	gboolean  res = FALSE;
-
-	key_file = g_key_file_new ();
-	res = g_key_file_load_from_file (key_file, source_path, 
-					 G_KEY_FILE_KEEP_COMMENTS|G_KEY_FILE_KEEP_TRANSLATIONS,
-					 error);
-	if (!res) {
-		g_key_file_free (key_file);
-		return FALSE;
-	}
-
-	res = panel_key_file_to_file (key_file, target_path, error);
-
-	g_key_file_free (key_file);
-
-	return res;
-}
-
 gboolean
 panel_key_file_get_boolean (GKeyFile    *keyfile,
 			    const gchar *key,
@@ -272,39 +248,6 @@ panel_key_file_set_locale_string (GKeyFile    *keyfile,
 				       key, value);
 }
 
-void
-panel_key_file_remove_locale_key (GKeyFile    *keyfile,
-				  const gchar *key)
-{
-	const char * const *langs_pointer;
-	int                 i;
-	char               *locale_key;
-
-	locale_key = NULL;
-	langs_pointer = g_get_language_names ();
-	for (i = 0; langs_pointer[i] != NULL; i++) {
-		/* find first without encoding  */
-		if (strchr (langs_pointer[i], '.') == NULL) {
-			locale_key = g_strdup_printf ("%s[%s]",
-						      key, langs_pointer[i]);
-			if (g_key_file_has_key (keyfile, G_KEY_FILE_DESKTOP_GROUP,
-						locale_key, NULL))
-				break;
-
-			g_free (locale_key);
-			locale_key = NULL;
-		}
-	}
-
-	if (locale_key) {
-		g_key_file_remove_key (keyfile, G_KEY_FILE_DESKTOP_GROUP,
-				       locale_key, NULL);
-		g_free (locale_key);
-	} else
-		g_key_file_remove_key (keyfile, G_KEY_FILE_DESKTOP_GROUP,
-				       key, NULL);
-}
-
 void
 panel_key_file_remove_all_locale_key (GKeyFile    *keyfile,
 				      const gchar *key)
