@@ -39,7 +39,6 @@
 #include "panel-lockdown.h"
 #include "panel-object-loader.h"
 #include "panel-schemas.h"
-#include "panel-stock-icons.h"
 
 #include <libpanel-applet-private/panel-applet-frame-dbus.h>
 #include "panel-applet-frame.h"
@@ -62,10 +61,6 @@ struct _PanelAppletFrameActivating {
 
 /* PanelAppletFrame implementation */
 
-G_DEFINE_TYPE (PanelAppletFrame, panel_applet_frame, GTK_TYPE_EVENT_BOX)
-
-#define PANEL_APPLET_FRAME_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_APPLET_FRAME, PanelAppletFramePrivate))
-
 #define HANDLE_SIZE 10
 
 struct _PanelAppletFramePrivate {
@@ -91,6 +86,8 @@ enum {
 
 static guint panel_applet_frame_signals [LAST_SIGNAL];
 
+G_DEFINE_TYPE_WITH_PRIVATE (PanelAppletFrame, panel_applet_frame, GTK_TYPE_EVENT_BOX)
+
 static gboolean
 panel_applet_frame_draw (GtkWidget *widget,
                          cairo_t   *cr)
@@ -483,8 +480,6 @@ panel_applet_frame_class_init (PanelAppletFrameClass *klass)
 	add_tab_bindings (binding_set, GDK_SHIFT_MASK, GTK_DIR_TAB_BACKWARD);
 	add_tab_bindings (binding_set, GDK_CONTROL_MASK, GTK_DIR_TAB_FORWARD);
 	add_tab_bindings (binding_set, GDK_CONTROL_MASK | GDK_SHIFT_MASK, GTK_DIR_TAB_BACKWARD);
-
-	g_type_class_add_private (klass, sizeof (PanelAppletFramePrivate));
 }
 
 static void
@@ -492,7 +487,7 @@ panel_applet_frame_init (PanelAppletFrame *frame)
 {
 	GtkStyleContext *context;
 
-	frame->priv = PANEL_APPLET_FRAME_GET_PRIVATE (frame);
+	frame->priv = panel_applet_frame_get_instance_private (frame);
 
 	frame->priv->panel       = NULL;
 	frame->priv->orientation = PANEL_ORIENTATION_TOP;
@@ -720,6 +715,19 @@ panel_applet_frame_activating_get_settings_path (PanelAppletFrameActivating *fra
 	return path_instance;
 }
 
+gchar *
+panel_applet_frame_activating_get_initial_settings_path (PanelAppletFrameActivating *frame_act)
+{
+        char *path;
+        char *path_instance;
+
+        g_object_get (frame_act->settings, "path", &path, NULL);
+        path_instance = g_strdup_printf ("%sinitial-settings/", path);
+        g_free (path);
+
+        return path_instance;
+}
+
 static void
 panel_applet_frame_loading_failed_response (GtkWidget *dialog,
 					    guint      response,
@@ -869,14 +877,16 @@ void
 panel_applet_frame_create (PanelToplevel       *toplevel,
 			   PanelObjectPackType  pack_type,
 			   int                  pack_index,
-			   const char          *iid)
+			   const char          *iid,
+			   GVariant            *initial_settings)
 {
 	g_return_if_fail (iid != NULL);
 
 	panel_layout_object_create (PANEL_OBJECT_APPLET,
 				    iid,
 				    panel_toplevel_get_id (toplevel),
-				    pack_type, pack_index);
+				    pack_type, pack_index,
+				    initial_settings);
 }
 
 gboolean
