@@ -23,6 +23,7 @@
 
 #include <glib-object.h>
 
+#include "libgnome-panel/gp-initial-setup-dialog-private.h"
 #include "panel-applet-frame.h"
 #include "panel-applet-info.h"
 
@@ -35,16 +36,11 @@ G_BEGIN_DECLS
 #define PANEL_IS_APPLETS_MANAGER_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), PANEL_TYPE_APPLETS_MANAGER))
 #define PANEL_APPLETS_MANAGER_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), PANEL_TYPE_APPLETS_MANAGER, PanelAppletsManagerClass))
 
-/**
- * PANEL_APPLETS_MANAGER_EXTENSION_POINT_NAME:
- *
- * Extension point for #PanelAppletsManager functionality.
- **/
-#define PANEL_APPLETS_MANAGER_EXTENSION_POINT_NAME "panel-applets-manager"
-
 typedef struct _PanelAppletsManager		PanelAppletsManager;
 typedef struct _PanelAppletsManagerClass	PanelAppletsManagerClass;
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (PanelAppletsManager, g_object_unref)
+
 struct _PanelAppletsManagerClass {
 	GObjectClass parent_class;
 
@@ -58,9 +54,6 @@ struct _PanelAppletsManagerClass {
 	PanelAppletInfo  * (*get_applet_info)       (PanelAppletsManager  *manager,
 						     const gchar          *iid);
 
-	PanelAppletInfo  * (*get_applet_info_from_old_id) (PanelAppletsManager  *manager,
-							   const gchar          *iid);
-
 	gboolean           (*load_applet)           (PanelAppletsManager         *manager,
 						     const gchar                 *iid,
 						     PanelAppletFrameActivating  *frame_act);
@@ -68,6 +61,18 @@ struct _PanelAppletsManagerClass {
 	GtkWidget        * (*get_applet_widget)     (PanelAppletsManager         *manager,
 	                                             const gchar                 *iid,
 	                                             guint                        uid);
+
+	gchar            * (*get_new_iid)           (PanelAppletsManager         *manager,
+	                                             const gchar                 *old_iid);
+
+	gboolean           (*open_initial_setup_dialog) (PanelAppletsManager         *manager,
+	                                                 const gchar                 *iid,
+	                                                 GtkWindow                   *parent,
+	                                                 GpInitialSetupCallback       callback,
+	                                                 gpointer                     user_data,
+	                                                 GDestroyNotify               free_func);
+
+	GtkWidget        * (*get_standalone_menu)   (PanelAppletsManager         *manager);
 };
 
 struct _PanelAppletsManager {
@@ -82,7 +87,6 @@ gboolean          panel_applets_manager_factory_activate            (const gchar
 void              panel_applets_manager_factory_deactivate          (const gchar     *iid);
 
 PanelAppletInfo  *panel_applets_manager_get_applet_info             (const gchar     *iid);
-PanelAppletInfo  *panel_applets_manager_get_applet_info_from_old_id (const gchar     *iid);
 
 gboolean          panel_applets_manager_load_applet                 (const gchar                *iid,
 								     PanelAppletFrameActivating *frame_act);
@@ -90,6 +94,16 @@ gboolean          panel_applets_manager_load_applet                 (const gchar
 GtkWidget        *panel_applets_manager_get_applet_widget           (const gchar     *iid,
                                                                      guint            uid);
 
+gchar            *panel_applets_manager_get_new_iid                 (const gchar     *old_iid);
+
+gboolean          panel_applets_manager_open_initial_setup_dialog   (const gchar            *iid,
+                                                                     GtkWindow              *parent,
+                                                                     GpInitialSetupCallback  callback,
+                                                                     gpointer                user_data,
+                                                                     GDestroyNotify          free_func);
+
+GtkWidget        *panel_applets_manager_get_standalone_menu         (void);
+
 G_END_DECLS
 
 #endif /* __PANEL_APPLETS_MANAGER_H__ */
