@@ -27,6 +27,7 @@
 #include "applet.h"
 #include "button-widget.h"
 #include "launcher.h"
+#include "panel-applets-manager.h"
 #include "panel-bindings.h"
 #include "panel-context-menu.h"
 #include "panel-util.h"
@@ -34,7 +35,6 @@
 #include "panel-action-button.h"
 #include "panel-multiscreen.h"
 #include "panel-toplevel.h"
-#include "panel-menu-button.h"
 #include "panel-lockdown.h"
 #include "panel-icon-names.h"
 #include "panel-layout.h"
@@ -75,7 +75,6 @@ orientation_change (AppletInfo  *info,
 		panel_applet_frame_change_orientation (
 				PANEL_APPLET_FRAME (info->widget), orientation);
 		break;
-	case PANEL_OBJECT_MENU:
 	case PANEL_OBJECT_LAUNCHER:
 	case PANEL_OBJECT_ACTION:
 		button_widget_set_orientation (BUTTON_WIDGET (info->widget), orientation);
@@ -232,8 +231,7 @@ make_popup_panel_menu (PanelWidget *panel_widget)
 
 static gboolean
 panel_popup_menu (PanelToplevel *toplevel,
-		  guint          button,
-		  guint32        activate_time)
+                  GdkEvent      *event)
 {
 	PanelWidget *panel_widget;
 	GtkWidget   *menu;
@@ -247,7 +245,7 @@ panel_popup_menu (PanelToplevel *toplevel,
 	gtk_menu_set_screen (GTK_MENU (menu),
 			     gtk_window_get_screen (GTK_WINDOW (toplevel)));
 
-	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, button, activate_time);
+	gtk_menu_popup_at_pointer (GTK_MENU (menu), event);
 
 	return TRUE;
 }
@@ -264,7 +262,7 @@ panel_button_press_event (PanelToplevel  *toplevel,
 	modifiers = event->state & gtk_accelerator_get_default_mod_mask ();
 
 	if (modifiers == panel_bindings_get_mouse_button_modifier_keymask ())
-		return panel_popup_menu (toplevel, event->button, event->time);
+		return panel_popup_menu (toplevel, (GdkEvent *) event);
 
 	return FALSE;
 }
@@ -283,7 +281,7 @@ panel_key_press_event (PanelToplevel *toplevel,
 		panel_util_key_event_is_popup_panel (event, &is_popup, NULL);
 
 	if (is_popup)
-		return panel_popup_menu (toplevel, 3, event->time);
+		return panel_popup_menu (toplevel, (GdkEvent *) event);
 
 	return FALSE;
 }
@@ -432,24 +430,6 @@ drop_url (PanelWidget         *panel,
 	return TRUE;
 }
 
-static gboolean
-drop_menu (PanelWidget         *panel,
-	   PanelObjectPackType  pack_type,
-	   int                  pack_index,
-	   const char          *menu_filename,
-	   const char          *menu_path)
-{
-	if (!panel_layout_is_writable ())
-		return FALSE;
-
-	return panel_menu_button_create (panel->toplevel,
-					 pack_type, pack_index,
-					 menu_filename,
-					 menu_path,
-					 NULL);
-
-}
-
 static gboolean
 drop_uri (PanelWidget         *panel,
 	  PanelObjectPackType  pack_type,
@@ -513,7 +493,7 @@ drop_nautilus_desktop_uri (PanelWidget         *panel,
 
 	if (strncmp (basename, "trash", strlen ("trash")) == 0)
 		panel_applet_frame_create (panel->toplevel, pack_type, pack_index,
-					   "OAFIID:GNOME_Panel_TrashApplet");
+		                           "OAFIID:GNOME_Panel_TrashApplet", NULL);
 	else if (strncmp (basename, "home", strlen ("home")) == 0) {
 		char  *name;
 		char  *uri_tmp;
@@ -742,37 +722,6 @@ drop_internal_icon (PanelWidget         *panel,
 	return TRUE;
 }
 
-static gboolean
-move_applet (PanelWidget         *panel,
-	     PanelObjectPackType  pack_type,
-	     int                  pack_index,
-	     int                  applet_index)
-{
-	GSList     *applet_list;
-	AppletInfo *info;
-	GtkWidget  *parent;
-
-	applet_list = panel_applet_list_applets ();
-
-	info = g_slist_nth_data (applet_list, applet_index);
-
-	if (info == NULL || info->widget == NULL ||
-	    !panel_applet_can_freely_move (info))
-		return FALSE;
-
-	parent = gtk_widget_get_parent (info->widget);
-
-	if (parent != NULL &&
-	    PANEL_IS_WIDGET (parent)) {
-		panel_widget_reparent (PANEL_WIDGET (parent),
-				       panel,
-				       info->widget,
-				       pack_type, pack_index);
-	}
-
-	return TRUE;
-}
-
 static gboolean
 drop_internal_applet (PanelWidget         *panel,
 		      PanelObjectPackType  pack_type,
@@ -787,36 +736,7 @@ drop_internal_applet (PanelWidget         *panel,
 	if (applet_type == NULL)
 		return FALSE;
 
-	if (sscanf (applet_type, "MENU:%d", &applet_index) == 1) {
-		if (action != GDK_ACTION_MOVE)
-			g_warning ("Only MOVE supported for menus");
-		success = move_applet (panel, pack_type, pack_index, applet_index);
-
-	} else if (strncmp (applet_type, "MENU:", strlen ("MENU:")) == 0) {
-		const char *menu;
-		const char *menu_path;
-
-		menu = &applet_type[strlen ("MENU:")];
-		menu_path = strchr (menu, '/');
-
-		if (!menu_path) {
-			if (strncmp (menu, "MAIN", strlen ("MAIN")) == 0)
-				success = drop_menu (panel, pack_type, pack_index,
-						     NULL, NULL);
-			else
-				success = drop_menu (panel, pack_type, pack_index,
-						     menu, NULL);
-		} else {
-			char *menu_filename;
-
-			menu_filename = g_strndup (menu, menu_path - menu);
-			menu_path++;
-			success = drop_menu (panel, pack_type, pack_index,
-					     menu_filename, menu_path);
-			g_free (menu_filename);
-		}
-
-	} else if (!strncmp (applet_type, "ACTION:", strlen ("ACTION:"))) {
+	if (!strncmp (applet_type, "ACTION:", strlen ("ACTION:"))) {
 		if (panel_layout_is_writable ()) {
 			remove_applet = panel_action_button_load_from_drag (
 							panel->toplevel,
@@ -1035,6 +955,81 @@ drag_leave_cb (GtkWidget	*widget,
 	panel_toplevel_queue_auto_hide (toplevel);
 }
 
+
+typedef struct
+{
+	PanelWidget         *panel;
+
+	GdkDragContext      *context;
+	guint                time;
+
+	PanelObjectPackType  pack_type;
+	int                  pack_index;
+	gchar               *iid;
+} InitialSetupData;
+
+static InitialSetupData *
+initial_setup_data_new (PanelWidget         *panel,
+                        GdkDragContext      *context,
+                        guint                time,
+                        PanelObjectPackType  pack_type,
+                        int                  pack_index,
+                        const gchar         *iid)
+{
+	InitialSetupData *data;
+
+	data = g_new0 (InitialSetupData, 1);
+
+	data->panel = panel;
+
+	data->context = context;
+	data->time = time;
+
+	data->pack_type = pack_type;
+	data->pack_index = pack_index;
+	data->iid = g_strdup (iid);
+
+	return data;
+}
+
+static void
+initial_setup_data_free (gpointer user_data)
+{
+	InitialSetupData *data;
+
+	data = (InitialSetupData *) user_data;
+
+	g_free (data->iid);
+	g_free (data);
+}
+
+static void
+initial_setup_dialog_cb (GpInitialSetupDialog *dialog,
+                         gboolean              canceled,
+                         gpointer              user_data)
+{
+	InitialSetupData *data;
+	GVariant *initial_settings;
+
+	data = (InitialSetupData *) user_data;
+
+	if (canceled) {
+		gtk_drag_finish (data->context, FALSE, FALSE, data->time);
+		return;
+	}
+
+	initial_settings = gp_initital_setup_dialog_get_settings (dialog);
+
+	panel_applet_frame_create (data->panel->toplevel,
+	                           data->pack_type,
+	                           data->pack_index,
+	                           data->iid,
+	                           initial_settings);
+
+	gtk_drag_finish (data->context, TRUE, FALSE, data->time);
+	g_variant_unref (initial_settings);
+}
+
 static void
 panel_receive_dnd_data (PanelWidget         *panel,
 			guint                info,
@@ -1080,10 +1075,25 @@ panel_receive_dnd_data (PanelWidget         *panel,
 			return;
 		}
 		if (panel_layout_is_writable ()) {
-			panel_applet_frame_create (panel->toplevel,
-						   pack_type, pack_index,
-						   (char *) data);
-			success = TRUE;
+			InitialSetupData *initial_setup_data;
+
+			initial_setup_data = initial_setup_data_new (panel, context, time_,
+			                                             pack_type, pack_index,
+			                                             (char *) data);
+
+			if (!panel_applets_manager_open_initial_setup_dialog ((char *) data,
+			                                                      NULL,
+			                                                      initial_setup_dialog_cb,
+			                                                      initial_setup_data,
+			                                                      initial_setup_data_free)) {
+				panel_applet_frame_create (panel->toplevel,
+				                           pack_type, pack_index,
+				                           (char *) data, NULL);
+
+				success = TRUE;
+			} else {
+				return;
+			}
 		} else {
 			success = FALSE;
 		}
